﻿using System;
using System.ComponentModel;
using System.Windows;

namespace ThinkGeoMapTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged, IDisposable
    {
        private MapControl _mapControl;
        private int _counter = 0;
        private bool _disposed = false;

        public MainWindow()
        {
            InitializeComponent();
            DataContext = this;
        }

        public MapControl MapControl
        {
            get { return _mapControl; }
            set
            {
                if (value != _mapControl)
                {
                    _mapControl = value;
                    OnPropertyChanged("MapControl");
                }
            }
        }

        public string CounterStatus { get { return _counter.ToString(); } }         

        private void AddMapStep()
        {
            MapControl = new MapControl();
            MapControl.MapLoaded += MapControl_MapLoaded;
            _disposed = false;
        }

        private void MapControl_MapLoaded(object sender, EventArgs e)
        {
            DisposeStep();
        }

        public void DisposeStep()
        {
            Dispose();
            _counter++;
            OnPropertyChanged("CounterStatus");
            AddMapStep();
        }

        private void StartButton_Click(object sender, RoutedEventArgs e)
        {
            StartStopButton.Content = "Wait";
            StartStopButton.IsEnabled = false;
            AddMapStep();
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }             

        private void Dispose(bool disposing)
        {
            if (_disposed) return;

            MapControl.MapLoaded -= MapControl_MapLoaded;
            MapControl.Dispose();
            MapControl = null;

            _disposed = true;
        }

        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }
    }
}
