﻿using System;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ThinkGeoMapTest
{
    /// <summary>
    /// Interaction logic for MapControl.xaml
    /// </summary>
    public partial class MapControl : UserControl, IDisposable
    {
        private LayerOverlay _overlayInstance;
        private bool _disposed = false;

        public event EventHandler MapLoaded = delegate { };

        public MapControl()
        {
            InitializeComponent();
        }

        private async void ThinkGeoWpfMap_Loaded(object sender, System.Windows.RoutedEventArgs e)
        {
            CadFeatureLayer cadFeatureLayer = new CadFeatureLayer(@"..\..\CADFiles\trinidad-tobago.dxf");
            cadFeatureLayer.StylingType = CadStylingType.EmbeddedStyling;
            _overlayInstance = new LayerOverlay();
            _overlayInstance.Layers.Add("CAD layer", cadFeatureLayer);

            await this.Dispatcher.BeginInvoke((Action)(() =>
            {
                ThinkGeoWpfMap.Overlays.Add(_overlayInstance);
                cadFeatureLayer.Open();
                ThinkGeoWpfMap.CurrentExtent = cadFeatureLayer.GetBoundingBox();
                cadFeatureLayer.Close();
                ThinkGeoWpfMap.Refresh();
            }));
            
            _disposed = false;
            InvokeMapLoadedEvent();
        }

        private void InvokeMapLoadedEvent()
        {
            MapLoaded.Invoke(this, EventArgs.Empty);
        }

        private void Dispose(bool disposing)
        {
            if (_disposed) return;

            foreach (var layer in _overlayInstance.Layers)
                layer.Close();
            _overlayInstance.Layers.Clear();
            _overlayInstance.Dispose();
            _overlayInstance = null;

            foreach (var overlay in ThinkGeoWpfMap.Overlays)
                overlay.Dispose();
            ThinkGeoWpfMap.Overlays.Clear();
            ThinkGeoWpfMap.Dispose();
            ThinkGeoWpfMap = null;

            _disposed = true;
        }

        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }
    }
}
